==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppAzureStorageAccountsSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.kotlin.outputs.AzureStorageInfoValueResponse
import com.pulumi.azurenative.web.kotlin.outputs.AzureStorageInfoValueResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [WebAppAzureStorageAccountsSlot].
 */
@PulumiTagMarker
public class WebAppAzureStorageAccountsSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppAzureStorageAccountsSlotArgs = WebAppAzureStorageAccountsSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppAzureStorageAccountsSlotArgsBuilder.() -> Unit) {
        val builder = WebAppAzureStorageAccountsSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebAppAzureStorageAccountsSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppAzureStorageAccountsSlot(builtJavaResource)
    }
}

/**
 * AzureStorageInfo dictionary resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppAzureStorageAccountsSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/config/azurestorageaccounts
 * ```
 */
public class WebAppAzureStorageAccountsSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot,
) : KotlinCustomResource(javaResource, WebAppAzureStorageAccountsSlotMapper) {
    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure storage accounts.
     */
    public val properties: Output<Map<String, AzureStorageInfoValueResponse>>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value.let({ args0 -> toKotlin(args0) }))
            }).toMap()
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppAzureStorageAccountsSlotMapper : ResourceMapper<WebAppAzureStorageAccountsSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppAzureStorageAccountsSlot =
        WebAppAzureStorageAccountsSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot,
        )
}

/**
 * @see [WebAppAzureStorageAccountsSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppAzureStorageAccountsSlot].
 */
public suspend fun webAppAzureStorageAccountsSlot(
    name: String,
    block: suspend WebAppAzureStorageAccountsSlotResourceBuilder.() -> Unit,
):
    WebAppAzureStorageAccountsSlot {
    val builder = WebAppAzureStorageAccountsSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppAzureStorageAccountsSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppAzureStorageAccountsSlot(name: String): WebAppAzureStorageAccountsSlot {
    val builder = WebAppAzureStorageAccountsSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppAzureStorageAccountsSlot.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.kotlin.outputs.AzureStorageInfoValueResponse
import com.pulumi.azurenative.web.kotlin.outputs.AzureStorageInfoValueResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [WebAppAzureStorageAccountsSlot].
 */
@PulumiTagMarker
public class WebAppAzureStorageAccountsSlotResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppAzureStorageAccountsSlotArgs = WebAppAzureStorageAccountsSlotArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppAzureStorageAccountsSlotArgsBuilder.() -> Unit) {
        val builder = WebAppAzureStorageAccountsSlotArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppAzureStorageAccountsSlot {
        val builtJavaResource =
            com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WebAppAzureStorageAccountsSlot(builtJavaResource)
    }
}

/**
 * AzureStorageInfo dictionary resource.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppAzureStorageAccountsSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/config/azurestorageaccounts
 * ```
 */
public class WebAppAzureStorageAccountsSlot internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot,
) : KotlinCustomResource(javaResource, WebAppAzureStorageAccountsSlotMapper) {
    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure storage accounts.
     */
    public val properties: Output<Map<String, AzureStorageInfoValueResponse>>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.key.to(args0.value.let({ args0 -> toKotlin(args0) }))
            }).toMap()
        })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppAzureStorageAccountsSlotMapper : ResourceMapper<WebAppAzureStorageAccountsSlot> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot::class == javaResource::class

    override fun map(javaResource: Resource): WebAppAzureStorageAccountsSlot =
        WebAppAzureStorageAccountsSlot(
            javaResource as
                com.pulumi.azurenative.web.WebAppAzureStorageAccountsSlot,
        )
}

/**
 * @see [WebAppAzureStorageAccountsSlot].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppAzureStorageAccountsSlot].
 */
public suspend fun webAppAzureStorageAccountsSlot(
    name: String,
    block: suspend WebAppAzureStorageAccountsSlotResourceBuilder.() -> Unit,
):
    WebAppAzureStorageAccountsSlot {
    val builder = WebAppAzureStorageAccountsSlotResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppAzureStorageAccountsSlot].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppAzureStorageAccountsSlot(name: String): WebAppAzureStorageAccountsSlot {
    val builder = WebAppAzureStorageAccountsSlotResourceBuilder()
    builder.name(name)
    return builder.build()
}
